@@ -8,15 +8,16 @@ PATH = str(Path(__file__).parent.absolute()) + "/"
 
 # Folder for the log files
 LOG_FOLDER = "{}/logs/".format(PATH)
-LOG_LEVEL = logging.INFO
+LOG_LEVEL = logging.DEBUG
 
 #Folder for the jobs
 PDF_REPORT_JOB_FOLDER = os.environ.get("PDF_REPORT_JOB_FOLDER")
 
 # Configuration for Superset-API
-HOST_PROTOCOL = os.environ.get("HOST_PROTOCOL")
-HOST_NAME = os.environ.get("HOST_NAME")
-SUPERSET_URL = "{}://{}".format(HOST_PROTOCOL, HOST_NAME)
+HOST_PROTOCOL = os.environ.get("WEBSERVER_PROTOCOL")
+HOST_NAME = os.environ.get("WEBSERVER_ADDRESS")
+SUPERSET_PORT = os.environ.get("WEBSERVER_PORT")
+SUPERSET_URL = "{}://{}:{}".format(HOST_PROTOCOL, HOST_NAME, SUPERSET_PORT)
 SUPERSET_API_USER = os.environ.get("SUPERSET_API_USER")
 SUPERSET_API_PASSWORD = os.environ.get("SUPERSET_API_PASSWORD")
 
@@ -33,4 +34,4 @@ SMTP_SSL = True
 NEXTCLOUD_URL = os.environ.get("NEXTCLOUD_URL")
 NEXTCLOUD_USER = os.environ.get("NEXTCLOUD_USER")
 NEXTCLOUD_PASSWORD = os.environ.get("NEXTCLOUD_PASSWORD")
-NEXTCLOUD_FOLDER = "superset_pdf_report"
+NEXTCLOUD_FOLDER = os.environ.get("NEXTCLOUD_FOLDER")
